Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type KubeNodeGroup ¶
KubeNodeGroup is an autogenerated mock type for the KubeNodeGroup type
func NewKubeNodeGroup ¶ added in v0.150.0
func NewKubeNodeGroup(t interface {
mock.TestingT
Cleanup(func())
}) *KubeNodeGroup
NewKubeNodeGroup creates a new instance of KubeNodeGroup. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*KubeNodeGroup) GetAMIFamily ¶
func (_m *KubeNodeGroup) GetAMIFamily() string
GetAMIFamily provides a mock function with no fields
func (*KubeNodeGroup) ListOptions ¶
func (_m *KubeNodeGroup) ListOptions() v1.ListOptions
ListOptions provides a mock function with no fields
func (*KubeNodeGroup) NameString ¶
func (_m *KubeNodeGroup) NameString() string
NameString provides a mock function with no fields
func (*KubeNodeGroup) Size ¶
func (_m *KubeNodeGroup) Size() int
Size provides a mock function with no fields
Click to show internal directories.
Click to hide internal directories.