Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Queue ¶
type Queue struct {
// ContentBasedDeduplication AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-contentbaseddeduplication
ContentBasedDeduplication *types.Value `json:"ContentBasedDeduplication,omitempty"`
// DeduplicationScope AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-deduplicationscope
DeduplicationScope *types.Value `json:"DeduplicationScope,omitempty"`
// DelaySeconds AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-delayseconds
DelaySeconds *types.Value `json:"DelaySeconds,omitempty"`
// FifoQueue AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-fifoqueue
FifoQueue *types.Value `json:"FifoQueue,omitempty"`
// FifoThroughputLimit AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-fifothroughputlimit
FifoThroughputLimit *types.Value `json:"FifoThroughputLimit,omitempty"`
// KmsDataKeyReusePeriodSeconds AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-kmsdatakeyreuseperiodseconds
KmsDataKeyReusePeriodSeconds *types.Value `json:"KmsDataKeyReusePeriodSeconds,omitempty"`
// KmsMasterKeyId AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-kmsmasterkeyid
KmsMasterKeyId *types.Value `json:"KmsMasterKeyId,omitempty"`
// MaximumMessageSize AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-maximummessagesize
MaximumMessageSize *types.Value `json:"MaximumMessageSize,omitempty"`
// MessageRetentionPeriod AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-messageretentionperiod
MessageRetentionPeriod *types.Value `json:"MessageRetentionPeriod,omitempty"`
// QueueName AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-queuename
QueueName *types.Value `json:"QueueName,omitempty"`
// ReceiveMessageWaitTimeSeconds AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-receivemessagewaittimeseconds
ReceiveMessageWaitTimeSeconds *types.Value `json:"ReceiveMessageWaitTimeSeconds,omitempty"`
// RedriveAllowPolicy AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-redriveallowpolicy
RedriveAllowPolicy interface{} `json:"RedriveAllowPolicy,omitempty"`
// RedrivePolicy AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-redrivepolicy
RedrivePolicy interface{} `json:"RedrivePolicy,omitempty"`
// SqsManagedSseEnabled AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-sqsmanagedsseenabled
SqsManagedSseEnabled *types.Value `json:"SqsManagedSseEnabled,omitempty"`
// Tags AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-tags
Tags []cloudformation.Tag `json:"Tags,omitempty"`
// VisibilityTimeout AWS CloudFormation Property
// Required: false
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html#cfn-sqs-queue-visibilitytimeout
VisibilityTimeout *types.Value `json:"VisibilityTimeout,omitempty"`
// AWSCloudFormationDeletionPolicy represents a CloudFormation DeletionPolicy
AWSCloudFormationDeletionPolicy policies.DeletionPolicy `json:"-"`
// AWSCloudFormationUpdateReplacePolicy represents a CloudFormation UpdateReplacePolicy
AWSCloudFormationUpdateReplacePolicy policies.UpdateReplacePolicy `json:"-"`
// AWSCloudFormationDependsOn stores the logical ID of the resources to be created before this resource
AWSCloudFormationDependsOn []string `json:"-"`
// AWSCloudFormationMetadata stores structured data associated with this resource
AWSCloudFormationMetadata map[string]interface{} `json:"-"`
// AWSCloudFormationCondition stores the logical ID of the condition that must be satisfied for this resource to be created
AWSCloudFormationCondition string `json:"-"`
}
Queue AWS CloudFormation Resource (AWS::SQS::Queue) See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queue.html
func (*Queue) AWSCloudFormationType ¶
AWSCloudFormationType returns the AWS CloudFormation resource type
func (Queue) MarshalJSON ¶
MarshalJSON is a custom JSON marshalling hook that embeds this object into an AWS CloudFormation JSON resource's 'Properties' field and adds a 'Type'.
func (*Queue) UnmarshalJSON ¶
UnmarshalJSON is a custom JSON unmarshalling hook that strips the outer AWS CloudFormation resource object, and just keeps the 'Properties' field.
type QueueInlinePolicy ¶ added in v0.206.0
type QueueInlinePolicy struct {
// PolicyDocument AWS CloudFormation Property
// Required: true
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queueinlinepolicy.html#cfn-sqs-queueinlinepolicy-policydocument
PolicyDocument interface{} `json:"PolicyDocument,omitempty"`
// Queue AWS CloudFormation Property
// Required: true
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queueinlinepolicy.html#cfn-sqs-queueinlinepolicy-queue
Queue *types.Value `json:"Queue,omitempty"`
// AWSCloudFormationDeletionPolicy represents a CloudFormation DeletionPolicy
AWSCloudFormationDeletionPolicy policies.DeletionPolicy `json:"-"`
// AWSCloudFormationUpdateReplacePolicy represents a CloudFormation UpdateReplacePolicy
AWSCloudFormationUpdateReplacePolicy policies.UpdateReplacePolicy `json:"-"`
// AWSCloudFormationDependsOn stores the logical ID of the resources to be created before this resource
AWSCloudFormationDependsOn []string `json:"-"`
// AWSCloudFormationMetadata stores structured data associated with this resource
AWSCloudFormationMetadata map[string]interface{} `json:"-"`
// AWSCloudFormationCondition stores the logical ID of the condition that must be satisfied for this resource to be created
AWSCloudFormationCondition string `json:"-"`
}
QueueInlinePolicy AWS CloudFormation Resource (AWS::SQS::QueueInlinePolicy) See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queueinlinepolicy.html
func (*QueueInlinePolicy) AWSCloudFormationType ¶ added in v0.206.0
func (r *QueueInlinePolicy) AWSCloudFormationType() string
AWSCloudFormationType returns the AWS CloudFormation resource type
func (QueueInlinePolicy) MarshalJSON ¶ added in v0.206.0
func (r QueueInlinePolicy) MarshalJSON() ([]byte, error)
MarshalJSON is a custom JSON marshalling hook that embeds this object into an AWS CloudFormation JSON resource's 'Properties' field and adds a 'Type'.
func (*QueueInlinePolicy) UnmarshalJSON ¶ added in v0.206.0
func (r *QueueInlinePolicy) UnmarshalJSON(b []byte) error
UnmarshalJSON is a custom JSON unmarshalling hook that strips the outer AWS CloudFormation resource object, and just keeps the 'Properties' field.
type QueuePolicy ¶
type QueuePolicy struct {
// PolicyDocument AWS CloudFormation Property
// Required: true
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queuepolicy.html#cfn-sqs-queuepolicy-policydocument
PolicyDocument interface{} `json:"PolicyDocument,omitempty"`
// Queues AWS CloudFormation Property
// Required: true
// See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queuepolicy.html#cfn-sqs-queuepolicy-queues
Queues *types.Value `json:"Queues,omitempty"`
// AWSCloudFormationDeletionPolicy represents a CloudFormation DeletionPolicy
AWSCloudFormationDeletionPolicy policies.DeletionPolicy `json:"-"`
// AWSCloudFormationUpdateReplacePolicy represents a CloudFormation UpdateReplacePolicy
AWSCloudFormationUpdateReplacePolicy policies.UpdateReplacePolicy `json:"-"`
// AWSCloudFormationDependsOn stores the logical ID of the resources to be created before this resource
AWSCloudFormationDependsOn []string `json:"-"`
// AWSCloudFormationMetadata stores structured data associated with this resource
AWSCloudFormationMetadata map[string]interface{} `json:"-"`
// AWSCloudFormationCondition stores the logical ID of the condition that must be satisfied for this resource to be created
AWSCloudFormationCondition string `json:"-"`
}
QueuePolicy AWS CloudFormation Resource (AWS::SQS::QueuePolicy) See: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-sqs-queuepolicy.html
func (*QueuePolicy) AWSCloudFormationType ¶
func (r *QueuePolicy) AWSCloudFormationType() string
AWSCloudFormationType returns the AWS CloudFormation resource type
func (QueuePolicy) MarshalJSON ¶
func (r QueuePolicy) MarshalJSON() ([]byte, error)
MarshalJSON is a custom JSON marshalling hook that embeds this object into an AWS CloudFormation JSON resource's 'Properties' field and adds a 'Type'.
func (*QueuePolicy) UnmarshalJSON ¶
func (r *QueuePolicy) UnmarshalJSON(b []byte) error
UnmarshalJSON is a custom JSON unmarshalling hook that strips the outer AWS CloudFormation resource object, and just keeps the 'Properties' field.