efa

package
v0.223.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 14, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsBuiltInSupported

func IsBuiltInSupported(kubernetesVersion string, isManagedNodeGroups bool) (bool, error)

IsBuiltInSupported returns true if the Kubernetes version supports built-in EFA in the default security group

func ProcessSecurityGroup

func ProcessSecurityGroup(config SecurityGroupConfig, addEFASecurityGroupFunc func(*gfnt.Value, string, string) *gfnt.Value, isManagedNodeGroups bool) (*gfnt.Value, error)

ProcessSecurityGroup handles the common EFA security group logic Returns the security group (nil if built-in EFA is used) and any error

Types

type SecurityGroupConfig

type SecurityGroupConfig struct {
	ClusterVersion string
	ClusterName    string
	NodeGroupName  string
	VPCID          *gfnt.Value
	Description    string
}

SecurityGroupConfig holds the configuration needed for EFA security group creation

Jump to